@@ -26,7 +26,7 @@ class Runtime:
     @staticmethod
     def check_runner_conn(connection: grpc.Channel):
         def cb(state: grpc.ChannelConnectivity):
-            if state == grpc.TRANSIENT_FAILURE or state == grpc.SHUTDOWN:
+            if state == grpc.ChannelConnectivity.TRANSIENT_FAILURE or state == grpc.ChannelConnectivity.SHUTDOWN:
                 Runtime.event.set()
 
         connection.subscribe(cb, True)
