@@ -15,7 +15,7 @@ class ECategory(IntEnum):
     Token = 4
     Database = 5
     Document = 6
-    
+
 
 class _DefVal:
     def __init__(self, default: object):
@@ -26,10 +26,15 @@ class _DefVal:
 
 
 class _Enum:
-    def __init__(self, enums: [], enumNames: []):
+    def __init__(self, enums: [], enumNames: [], description: str = ''):
+        self.__description = description
         self.__enums = enums
         self.__enumNames = enumNames
 
+    @property
+    def description(self) -> str:
+        return self.__description
+
     @property
     def enums(self):
         return self.__enums
@@ -40,14 +45,15 @@ class _Enum:
 
 
 class Variable:
-    def __init__(self, scope: str='', name: str='', title: str='', type: str='', pyScope: bool=False, customScope: bool=False,
-                 messageScope: bool=False, messageOnly: bool=False, hidden: bool=False, input: bool=False, output: bool=False,
-                 option: bool=False, default: _DefVal=None, enum: _Enum=None):
+    def __init__(self, scope: str = '', name: str = '', title: str = '', description: str = '', type: str = '', pyScope: bool = False, customScope: bool = False,
+                 messageScope: bool = False, messageOnly: bool = False, hidden: bool = False, input: bool = False, output: bool = False,
+                 option: bool = False, default: _DefVal = None, enum: _Enum = None, format: str = ''):
 
         self.__scope = scope
         self.__name = name
         self.__title = title
         self.__type = type
+        self.__description = description
         self.__pyScope = pyScope
         self.__customScope = customScope
         self.__messageScope = messageScope
@@ -58,6 +64,7 @@ class Variable:
         self.__isoption = option
         self.__default = default
         self.__enum = enum
+        self.__format = format
 
     @property
     def scope(self) -> str:
@@ -71,6 +78,10 @@ class Variable:
     def title(self) -> str:
         return self.__title
 
+    @property
+    def description(self) -> str:
+        return self.__description
+
     @property
     def type(self) -> str:
         return self.__type
@@ -114,11 +125,15 @@ class Variable:
     @property
     def enum(self) -> _Enum:
         return self.__enum
-        
+
     @property
     def category(self) -> ECategory:
         return ECategory.Null
 
+    @property
+    def format(self) -> str:
+        return self.__format
+
 
 class InVariable(Variable):
     def get(self, ctx: Context):
@@ -136,11 +151,18 @@ class OptVariable(Variable):
 
 
 class Credentials:
-    def __init__(self, vaultId: str='', itemId: str='', title: str='', category: ECategory=ECategory.Null):
+    def __init__(self, description: str = '', vaultId: str = '', itemId: str = '', title: str = '', category: ECategory = ECategory.Null, scope: str = '', name: str = ''):
+        self.__description = description
         self.__vaultId = vaultId
         self.__itemId = itemId
         self.__title = title
         self.__category = category
+        self.__scope = scope
+        self.__name = name
+
+    @property
+    def description(self) -> str:
+        return self.__description
 
     @property
     def vaultId(self) -> str:
@@ -158,10 +180,45 @@ class Credentials:
     def category(self) -> ECategory:
         return self.__category
 
-    def get_vault_item(self):
+    @property
+    def scope(self) -> str:
+        return self.__scope
+
+    @property
+    def name(self) -> str:
+        return self.__name
+
+    def get_vault_item(self, ctx: Context = None):
         if Runtime.client is None:
             return {}
 
-        request = plugin_pb2.GetVaultItemRequest(vaultId=self.vaultId, ItemId=self.itemId)
+        creds = None
+        if self.vaultId != '' and self.itemId != '':
+            creds = credentials(vaultId=self.vaultId, itemId=self.itemId)
+        else:
+            cr = self.name
+            if self.scope == 'Message':
+                v = InVariable(name=self.name, scope=self.scope)
+                cr = v.get(ctx=ctx)
+
+            creds = credentials(vaultId=cr['vaultId'], itemId=cr['itemId'])
+
+        request = plugin_pb2.GetVaultItemRequest(
+            vaultId=creds.vaultId, ItemId=creds.itemId
+        )
         response = Runtime.client.GetVaultItem(request)
         return json_format.MessageToDict(response.item)['value']
+
+
+class credentials:
+    def __init__(self, vaultId: str = '', itemId: str = ''):
+        self.__vaultId = vaultId
+        self.__itemId = itemId
+
+    @property
+    def vaultId(self) -> str:
+        return self.__vaultId
+
+    @property
+    def itemId(self) -> str:
+        return self.__itemId
